from setuptools import setup

setup(name='gb_distribution_package',
      version='0.2',
      description='Gaussian distributions',
      packages=['gb_distribution_package'],
      author = 'Prashant Kumar',
      author_email = 'mail2pk1105@gmail.com',
      zip_safe=False)
